"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBranchDiff = createBranchDiff;
exports.getGitProjectId = getGitProjectId;
exports.requestGit = requestGit;
exports.requestUtils = requestUtils;
var _child_process = require("child_process");
var _fs = require("fs");
var _fileUtils = require("./fileUtils");
var _getSonarProperties = require("../core/sonar-dependencies/getSonarProperties");
var _hash = require("./hash");
var _logger = require("./logger");
async function requestGit(apiDetails, options = {}) {
  const {
    action,
    headers,
    endPoint
  } = apiDetails;
  const body = {
    method: action,
    headers: headers
  };
  return await new Promise(resolve => {
    const request = https.request(endPoint, body, response => {
      var responseChunk = "";
      const fileStream = fs.createWriteStream(getLocalBranchPath());
      response.on("data", data => {
        responseChunk += data;
      });
      response.pipe(fileStream);
      fileStream.on("finish", finish => {
        fileStream.close();
      });
      response.on("error", error => {
        _logger.Logger.log(_logger.Logger.FAILURE_TYPE, `Error - ${error}`);
      });
      response.on("end", end => {
        // at end
        resolve({});
      });
    });
    request.end();
  });
}

/**
 *@function requestUtils - method execute curl cli request
 * @returns {Promise<Buffer>}
 */

function requestUtils(command) {
  return (0, _child_process.execSync)(command, {
    shell: true
  });
}

/**
 * @function createBranchDiff - make giff diff api via curl api
 * @returns {void}
 */

function createBranchDiff() {
  var command;
  var {
    token,
    gitEndPoint,
    branchDiffPath,
    compareBranch,
    projectId
  } = (0, _fileUtils.getLintConfiguration)();
  if (projectId == "project-id") {
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, `make sure that project id is properly configured`);
    projectId = getGitProjectId();
  }
  const endPoint = `${gitEndPoint}/api/v4/projects/${projectId}/repository/compare?from=${compareBranch}&to=${(0, _getSonarProperties.getBranchName)()}`;
  try {
    command = `curl --header "PRIVATE-TOKEN:${(0, _hash.decrypt)(token, 12)}" "${endPoint}"`;
    (0, _fs.writeFileSync)(branchDiffPath, requestUtils(command));
  } catch (err) {
    _logger.Logger.log(_logger.Logger.INFO_TYPE, `INFO : If you are using a VPN and encounter an SSL certification issue, ensure that the proxy is enabled for SSH and shell connections.`);
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, `make sure that you have access to this repository ${(0, _getSonarProperties.getRepoName)()}`);
  }
}
function getGitProjectId() {
  var command;
  const {
    token,
    gitEndPoint
  } = (0, _fileUtils.getLintConfiguration)();
  const endPoint = `${gitEndPoint}/api/v4/projects?search=${(0, _getSonarProperties.getRepoName)()}`;
  try {
    command = (0, _child_process.execSync)(`curl --header "PRIVATE-TOKEN:${(0, _hash.decrypt)(token, 12)}" "${endPoint}"`);
    return JSON.parse(command.toString()).pop().id;
  } catch (err) {
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, `make sure that you have access to this repository ${(0, _getSonarProperties.getRepoName)()}`);
    _logger.Logger.log(_logger.Logger.INFO_TYPE, err);
  }
}